@@ -16,17 +16,18 @@ def sender(config: ConfigParser, populatecache: bool):
     for e in raw_lines:
         lines.append(e.strip())
     news, id_list = feed.get_to_publish(lines)
-    print(id_list)
     if len(news) > 0:
         with open(config["cache"]["cachefile"], "a+") as file:
             file.write(id_list)
         if not populatecache:
             # We can send the message
+            news, id_list = feed.get_to_publish(lines)
             try:
                 config["feed"]["tweet"]
                 twitter_sender(config, news)
             except KeyError:
                 pass
+            news, id_list = feed.get_to_publish(lines)
             try:
                 config["feed"]["toot"]
                 mastodon_sender(config, news)
